@@ -33,7 +33,7 @@ namespace acommon {
       : IStream('\n'), file_(f), own_(own) {}
     ~FStream() {close();}
 
-    PosibErr<void> open(ParmStr, const char *);
+    PosibErr<void> open(ParmString, const char *);
     void close();
  
     operator bool() {return file_ != 0 && !feof(file_) && !ferror(file_);}
@@ -60,9 +60,9 @@ namespace acommon {
     // Will return false if there is no more data
     bool append_line(String &, char d);
 
-    // These perform raw io with any sort of formatting
+    // These perform raw io with any sort of formating
     bool read(void *, unsigned int i);
-    void write(ParmStr);
+    void write(ParmString);
     void write(char c);
     void write(const void *, unsigned int i);
 
@@ -90,8 +90,7 @@ namespace acommon {
     FStream & operator>> (String &);
     FStream & operator>> (unsigned int &);
     FStream & operator>> (int &);
-    FStream & operator<< (ParmStr);
-    FStream & operator<< (unsigned long);
+    FStream & operator<< (ParmString);
     FStream & operator<< (unsigned int);
     FStream & operator<< (int);
     FStream & operator<< (double);
