@@ -1,4 +1,4 @@
-// Copyright (c) 2001,2011
+// Copyright (c) 2001
 // Kevin Atkinson
 //
 // Permission to use, copy, modify, distribute and sell this software
@@ -24,9 +24,9 @@
 //   and hash_multimap which are very similar to SGI STL's implementation
 //   with a few notable exceptions.  The main one is that while 
 //   const_iterator is never invalided until the actual element is removed
-//   iterator is invalided my most all non-const member functions.  This
-//   is to simply the implementation slightly and allow the removal 
-//   of an element in guaranteed constant time when a non-const iterator
+//   iterator is invalded my most all non-const member functions.  This
+//   is to simply the implemenation slighly and allow the removial 
+//   of an element in garenteed constant time when a non-const iterator
 //   is provided rather that normally constant time.
 
 // All of the hash_* implementations are derived from the HashTable class
@@ -318,7 +318,7 @@ namespace acommon {
       : Base(s, Parms(h,e)) {}
     data_type & operator[](const key_type & k) 
     {
-      return (*((this->insert(value_type(k, data_type()))).first)).second;
+      return (*((insert(value_type(k, data_type()))).first)).second;
     }
   };
 
