@@ -24,10 +24,10 @@ namespace acommon
       this->push_back(t);
     }
     void append(const T * begin, unsigned int size) {
-      this->insert(this->end(), begin, begin+size);
+      insert(this->end(), begin, begin+size);
     }
     void append(const T * begin, const T * end) {
-      this->insert(this->end(), begin, end);
+      insert(this->end(), begin, end);
     }
     int alloc(int s) {
       int pos = this->size();
@@ -36,13 +36,13 @@ namespace acommon
     }
     T * data() {return &*this->begin();}
     T * data(int pos) {return &*this->begin() + pos;}
-    T * data_end() {return &*this->begin() + this->size();}
+    T * data_end() {return &*this->end();}
 
     T * pbegin() {return &*this->begin();}
-    T * pend()   {return &*this->begin() + this->size();}
+    T * pend()   {return &*this->end();}
 
     const T * pbegin() const {return &*this->begin();}
-    const T * pend()   const {return &*this->begin() + this->size();}
+    const T * pend()   const {return &*this->end();}
 
     template <typename U>
     U * datap() { 
@@ -52,9 +52,6 @@ namespace acommon
     U * datap(int pos) {
       return reinterpret_cast<U * >(&this->front() + pos);
     }
-
-    void pop_front() {this->erase(this->begin());}
-    void push_front(const T & v) {this->insert(this->begin(), v);}
   };
 }
 
